;; Generated package description from lv.el  -*- no-byte-compile: t -*-
(define-package "lv" "0.15.0" "Other echo area" 'nil :commit "54e9db2b023e03b6f6b46aeec48ea74fd51d4e11" :url "https://elpa.gnu.org/packages/lv.html")
